============
Installation
============

At the command line::

    $ pip install networking-plumgrid

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv networking-plumgrid
    $ pip install networking-plumgrid